# Data classes

## Image classification

::: nyckel.ImageClassificationSample
    options:
        show_source: true
        members: false
        heading_level: 3

::: nyckel.ImageSampleData
    options:
        show_source: true
        members: false
        heading_level: 3

## Text classification

::: nyckel.TextClassificationSample
    options:
        show_source: true
        members: false
        heading_level: 3

::: nyckel.TextSampleData
    options:
        show_source: true
        members: false
        heading_level: 3

## Tabular classification

::: nyckel.TabularClassificationSample
    options:
        show_source: true
        members: false
        heading_level: 3

::: nyckel.TabularSampleData
    options:
        show_source: true
        members: false
        heading_level: 3

::: nyckel.TabularFunctionField
    options:
        show_source: true
        members: false
        heading_level: 3

## Shared

::: nyckel.NyckelId
    options:
        show_source: true
        members: false
        heading_level: 3

::: nyckel.ClassificationLabel
    options:
        show_source: true
        members: false
        heading_level: 3

::: nyckel.ClassificationPrediction
    options:
        show_source: true
        members: false
        heading_level: 3

::: nyckel.ClassificationAnnotation
    options:
        show_source: true
        members: false
        heading_level: 3
